@@ -15,19 +15,19 @@ import unittest
 class GetViewsTest(test_base.UnitTest):
 
   def setUp(self):
-    super(GetViewsTest, self).setUp()
+    super().setUp()
     self._vm = vm.VirtualMachine(
         errors.ErrorLog(), config.Options.create(
             python_version=self.python_version),
         load_pytd.Loader(None, self.python_version))
 
   def test_basic(self):
-    v1 = self._vm.program.NewVariable(
-        [self._vm.convert.unsolvable], [], self._vm.root_cfg_node)
+    v1 = self._vm.program.NewVariable([self._vm.convert.unsolvable], [],
+                                      self._vm.root_node)
     v2 = self._vm.program.NewVariable(
         [self._vm.convert.int_type, self._vm.convert.str_type], [],
-        self._vm.root_cfg_node)
-    views = list(abstract_utils.get_views([v1, v2], self._vm.root_cfg_node))
+        self._vm.root_node)
+    views = list(abstract_utils.get_views([v1, v2], self._vm.root_node))
     six.assertCountEqual(self,
                          [{v1: views[0][v1], v2: views[0][v2]},
                           {v1: views[1][v1], v2: views[1][v2]}],
@@ -35,12 +35,12 @@ class GetViewsTest(test_base.UnitTest):
                           {v1: v1.bindings[0], v2: v2.bindings[1]}])
 
   def _test_optimized(self, skip_future_value, expected_num_views):
-    v1 = self._vm.program.NewVariable(
-        [self._vm.convert.unsolvable], [], self._vm.root_cfg_node)
+    v1 = self._vm.program.NewVariable([self._vm.convert.unsolvable], [],
+                                      self._vm.root_node)
     v2 = self._vm.program.NewVariable(
         [self._vm.convert.int_type, self._vm.convert.str_type], [],
-        self._vm.root_cfg_node)
-    views = abstract_utils.get_views([v1, v2], self._vm.root_cfg_node)
+        self._vm.root_node)
+    views = abstract_utils.get_views([v1, v2], self._vm.root_node)
     skip_future = None
     # To count the number of views. Doesn't matter what we put in here, as long
     # as it's one per view.
