@@ -500,11 +500,18 @@ class CallTracer(vm.VirtualMachine):
       options = var.FilteredData(self.exitpoint, strict=False)
       if (len(options) > 1 and
           not all(isinstance(o, abstract.FUNCTION_TYPES) for o in options)):
-        # It's ambiguous whether this is a type, a function or something
-        # else, so encode it as a constant.
-        combined_types = pytd_utils.JoinTypes(t.to_type(self.exitpoint)
-                                              for t in options)
-        data.append(pytd.Constant(name, combined_types))
+        if all(isinstance(o, (abstract.ParameterizedClass,
+                              abstract.TypeParameter,
+                              abstract.Union)) for o in options
+               ) and self.options.preserve_union_macros:  # type alias
+          data.append(pytd_utils.JoinTypes(t.to_pytd_def(self.exitpoint, name)
+                                           for t in options))
+        else:
+          # It's ambiguous whether this is a type, a function or something
+          # else, so encode it as a constant.
+          combined_types = pytd_utils.JoinTypes(t.to_type(self.exitpoint)
+                                                for t in options)
+          data.append(pytd.Constant(name, combined_types))
       elif options:
         for option in options:
           try:
@@ -729,9 +736,10 @@ def _maybe_output_debug(options, program):
   if options.output_cfg or options.output_typegraph:
     dot = debug.program_to_dot(program, set([]), bool(options.output_cfg))
     svg_file = options.output_cfg or options.output_typegraph
-    proc = subprocess.Popen(["/usr/bin/dot", "-T", "svg", "-o", svg_file],
-                            stdin=subprocess.PIPE, universal_newlines=True)
-    (_, stderr) = proc.communicate(dot)
+    with subprocess.Popen(
+        ["/usr/bin/dot", "-T", "svg", "-o", svg_file],
+        stdin=subprocess.PIPE, universal_newlines=True) as proc:
+      (_, stderr) = proc.communicate(dot)
     if stderr:
       log.info("Failed to create %s: %s", svg_file, stderr)
   if options.output_debug:
