@@ -1,12 +1,17 @@
 """Mixin for all class-like abstract classes."""
 
 import logging
+from typing import Any
+
+import attr
 
 from pytype import abstract_utils
 from pytype import datatypes
 from pytype import function
 from pytype import mixin
 from pytype.pytd import mro
+from pytype.pytd import pytd
+from pytype.pytd import visitors
 
 log = logging.getLogger(__name__)
 
@@ -32,6 +37,12 @@ def get_metadata_key(decorator):
   return _METADATA_KEYS.get(decorator)
 
 
+class AttributeKinds:
+  CLASSVAR = "classvar"
+  INITVAR = "initvar"
+
+
+@attr.s(auto_attribs=True)
 class Attribute:
   """Represents a class member variable.
 
@@ -41,28 +52,39 @@ class Attribute:
     init: Whether the field should be included in the generated __init__
     kw_only: Whether the field is kw_only in the generated __init__
     default: Default value
+    kind: Kind of attribute (see the AttributeKinds enum)
 
   Used in metadata (see Class.metadata below).
   """
 
-  def __init__(self, name, typ, init, kw_only, default, pytd_const=None):
-    self.name = name
-    self.typ = typ
-    self.init = init
-    self.kw_only = kw_only
-    self.default = default
-    # Store the pytd_const if we have generated this via from_pytd_constant.
-    self.pytd_const = pytd_const
+  name: str
+  typ: Any
+  init: bool
+  kw_only: bool
+  default: Any
+  kind: str = ""
+  pytd_const: Any = None
 
   @classmethod
-  def from_pytd_constant(cls, const, vm):
-    typ = vm.convert.constant_to_value(const.type)
-    val = const.value and vm.convert.constant_to_value(const.value)
+  def from_pytd_constant(cls, const, class_name, vm):
+    """Generate an Attribute from a pytd.Constant."""
+    # We cannot yet handle recursive type annotations in pyi dataclasses, so set
+    # them to Any without raising an exception.
+    typ = const.type.Visit(visitors.ClassTypeToAny(class_name))  # pytype: disable=attribute-error
+    typ = vm.convert.constant_to_value(typ)
+    # We want to generate the default from the type, not from the value
+    # (typically value will be Ellipsis or a similar placeholder).
+    val = const.value and typ.instantiate(vm.root_node)
     # Dataclasses and similar decorators in pytd files cannot set init and
     # kw_only properties.
     return cls(name=const.name, typ=typ, init=True, kw_only=False, default=val,
                pytd_const=const)
 
+  @classmethod
+  def from_param(cls, param, class_name, vm):
+    const = pytd.Constant(param.name, param.type, param.optional)
+    return cls.from_pytd_constant(const, class_name, vm)
+
   def to_pytd_constant(self):
     # TODO(mdemello): This is a bit fragile, but we only call this when
     # constructing a dataclass from a PyTDClass, where the initial Attribute
@@ -361,10 +383,10 @@ class Class(metaclass=mixin.MixinMeta):
       # indicates an annotation.
       if self.cls:
         # This class has a custom metaclass; check if it defines __getitem__.
-        _, attr = self.vm.attribute_handler.get_attribute(
+        _, att = self.vm.attribute_handler.get_attribute(
             node, self, name, self.to_binding(node))
-        if attr:
-          return attr
+        if att:
+          return att
       # Treat this class as a parameterized container in an annotation. We do
       # not need to worry about the class not being a container: in that case,
       # AnnotationContainer's param length check reports an appropriate error.
@@ -418,6 +440,10 @@ class Class(metaclass=mixin.MixinMeta):
           base_attrs.append(a)
     return base_attrs
 
+  def record_attr_ordering(self, own_attrs):
+    """Records the order of attrs to write in the output pyi."""
+    self.metadata["attr_order"] = own_attrs
+
   def compute_attr_metadata(self, own_attrs, decorator):
     """Sets combined metadata based on inherited and own attrs.
 
@@ -436,9 +462,3 @@ class Class(metaclass=mixin.MixinMeta):
     # Stash attributes in class metadata for subclasses.
     self.metadata[key] = attrs
     return attrs
-
-  def init_attr_metadata_from_pytd(self, decorator, fields):
-    """Initialise metadata[key] with a list of Attributes."""
-    # Called in abstract.PyTDClass.__init__
-    own_attrs = [Attribute.from_pytd_constant(c, self.vm) for c in fields]
-    self.compute_attr_metadata(own_attrs, decorator)
