@@ -155,22 +155,23 @@ def add_basic_options(o):
   temporary = ("This flag is temporary and will be removed once this behavior "
                "is enabled by default.")
   o.add_argument(
-      "--check-attribute-types", action="store_true",
-      dest="check_attribute_types", default=False,
-      help="Check attribute values against their annotations. " + temporary)
-  o.add_argument(
-      "--check-container-types", action="store_true",
-      dest="check_container_types", default=False,
-      help="Check container mutations against their annotations. " + temporary)
+      "--attribute-variable-annotations", action="store_true",
+      dest="attribute_variable_annotations", default=False,
+      help=("Apply PEP 526-style variable annotations on attributes. " +
+            temporary))
   o.add_argument(
       "--check-parameter-types", action="store_true",
       dest="check_parameter_types", default=False,
       help=("Check parameter defaults and assignments against their "
             "annotations. " + temporary))
   o.add_argument(
-      "--check-variable-types", action="store_true",
-      dest="check_variable_types", default=False,
-      help="Check variable values against their annotations. " + temporary)
+      "--create-pyi-dataclasses", action="store_true",
+      dest="create_pyi_dataclasses", default=False,
+      help="Construct a dataclass from a decorated pyi class. " + temporary)
+  o.add_argument(
+      "--preserve-union-macros", action="store_true",
+      dest="preserve_union_macros", default=False,
+      help="Preserve Union generic type aliases in pyi files. " + temporary)
 
 
 def add_subtools(o):
@@ -269,6 +270,10 @@ def add_infrastructure_options(o):
       "-Z", "--quick", action="store_true",
       dest="quick", default=None,
       help=("Only do an approximation."))
+  o.add_argument(
+      "--chex-overlay", action="store_true",
+      dest="chex_overlay", default=False,
+      help="Temporary flag to aid the release of an overlay for chex.dataclass")
 
 
 def add_debug_options(o):
