@@ -553,6 +553,7 @@ class Loader:
   def _load_ast_dependencies(self, dependencies, lookup_ast,
                              lookup_ast_name=None):
     """Fill in all ClassType.cls pointers and load reexported modules."""
+    ast_name = lookup_ast_name or lookup_ast.name
     for dep_name in dependencies:
       name = self._resolver.resolve_module_alias(
           dep_name, lookup_ast=lookup_ast, lookup_ast_name=lookup_ast_name)
@@ -565,37 +566,35 @@ class Loader:
         dep_ast = self._import_module_by_name(name)
         if dep_ast is None:
           dep_ast = self._try_import_prefix(name)
-          if dep_ast:
+          if dep_ast or f"{ast_name}.{name}" in lookup_ast:
             # If any prefix is a valid module, then we'll assume that we're
-            # importing a nested class.
+            # importing a nested class. If name is in lookup_ast, then it is a
+            # local reference and not an import at all.
             continue
           else:
             error = "Can't find pyi for %r" % name
-            raise BadDependencyError(error, lookup_ast_name or lookup_ast.name)
+            raise BadDependencyError(error, ast_name)
       # If `name` is a package, try to load any base names not defined in
       # __init__ as submodules.
-      if not self._modules[name].is_package():
+      if not self._modules[name].is_package() or "__getattr__" in dep_ast:
         continue
-      try:
-        dep_ast.Lookup("__getattr__")
-      except KeyError:
-        for base_name in dependencies[dep_name]:
-          if base_name == "*":
-            continue
-          full_name = "%s.%s" % (name, base_name)
-          # Check whether full_name is a submodule based on whether it is
-          # defined in the __init__ file.
-          try:
-            attr = dep_ast.Lookup(full_name)
-          except KeyError:
-            attr = None
-          # 'from . import submodule as submodule' produces
-          # Alias(submodule, NamedType(submodule)).
-          if attr is None or (
-              isinstance(attr, pytd.Alias) and attr.name == attr.type.name):
-            # Don't check the import result - resolve_external_types will raise
-            # a better error.
-            self._import_module_by_name(full_name)
+      for base_name in dependencies[dep_name]:
+        if base_name == "*":
+          continue
+        full_name = "%s.%s" % (name, base_name)
+        # Check whether full_name is a submodule based on whether it is
+        # defined in the __init__ file.
+        try:
+          attr = dep_ast.Lookup(full_name)
+        except KeyError:
+          attr = None
+        # 'from . import submodule as submodule' produces
+        # Alias(submodule, NamedType(submodule)).
+        if attr is None or (
+            isinstance(attr, pytd.Alias) and attr.name == attr.type.name):
+          # Don't check the import result - resolve_external_types will raise
+          # a better error.
+          self._import_module_by_name(full_name)
 
   def _resolve_external_types(self, mod_ast, mod_name=None):
     module_map = self._modules.get_module_map()
