@@ -41,8 +41,12 @@ class Dataclass(classgen.Decorator):
       return None
     # The InitVar annotation is not retained as a class member, but any default
     # value is retained.
-    del self.vm.annotated_locals[cls.name][name]
-    if orig is not None:
+    if orig is None:
+      # If an initvar does not have a default, it will not be a class member
+      # variable, so delete it from the annotated locals. Otherwise, leave the
+      # annotation as InitVar[...].
+      del self.vm.annotated_locals[cls.name][name]
+    else:
       cls.members[name] = classgen.instantiate(node, name, initvar)
     return initvar
 
@@ -66,6 +70,7 @@ class Dataclass(classgen.Decorator):
     cls_locals = self.get_class_locals(node, cls)
     for name, local in cls_locals.items():
       typ, orig = local.get_type(node, name), local.orig
+      kind = ""
       assert typ
       if match_classvar(typ):
         continue
@@ -73,6 +78,7 @@ class Dataclass(classgen.Decorator):
       if initvar_typ:
         typ = initvar_typ
         init = True
+        kind = classgen.AttributeKinds.INITVAR
       else:
         if not orig:
           cls.members[name] = classgen.instantiate(node, name, typ)
@@ -83,12 +89,7 @@ class Dataclass(classgen.Decorator):
         else:
           init = True
 
-      # TODO(b/74434237): The first check can be removed once
-      # --check-variable-types is on by default.
-      if ((not self.vm.options.check_variable_types and
-           local.last_op and
-           local.last_op.line in self.vm.director.type_comments) or
-          orig and orig.data == [self.vm.convert.none]):
+      if orig and orig.data == [self.vm.convert.none]:
         # vm._apply_annotation mostly takes care of checking that the default
         # matches the declared type. However, it allows None defaults, and
         # dataclasses do not.
@@ -96,9 +97,10 @@ class Dataclass(classgen.Decorator):
             node, name, typ, orig, local.stack, allow_none=False)
 
       attr = classgen.Attribute(
-          name=name, typ=typ, init=init, kw_only=False, default=orig)
+          name=name, typ=typ, init=init, kw_only=False, default=orig, kind=kind)
       own_attrs.append(attr)
 
+    cls.record_attr_ordering(own_attrs)
     attrs = cls.compute_attr_metadata(own_attrs, "dataclasses.dataclass")
 
     # Add an __init__ method if one doesn't exist already (dataclasses do not
@@ -107,6 +109,9 @@ class Dataclass(classgen.Decorator):
       init_method = self.make_init(node, cls, attrs)
       cls.members["__init__"] = init_method
 
+    if isinstance(cls, abstract.InterpreterClass):
+      cls.decorators.append("dataclasses.dataclass")
+
 
 class FieldInstance(abstract.SimpleValue):
   """Return value of a field() call."""
