@@ -331,12 +331,20 @@ class ParserTest(_ParserTestBase):
       def foo(x: int) -> int: ...
       def foo(x: str) -> str: ...""",
                """
+      from typing import overload
+
       @overload
       def foo(x: int) -> int: ...
       @overload
       def foo(x: str) -> str: ...""")
     # @overload decorators should be properly round-tripped.
     self.check("""
+      @overload
+      def foo(x: int) -> int: ...
+      @overload
+      def foo(x: str) -> str: ...""", """
+      from typing import overload
+
       @overload
       def foo(x: int) -> int: ...
       @overload
@@ -1122,6 +1130,8 @@ class FunctionTest(_ParserTestBase):
       @overload  # type: ignore  # unsupported signature
       def foo(bool) -> int: ...""",
                """
+      from typing import overload
+
       @overload
       def foo() -> int: ...
       @overload
@@ -1168,6 +1178,8 @@ class FunctionTest(_ParserTestBase):
       @coroutine
       def foo() -> str: ...""",
                """
+      from typing import overload
+
       @coroutine
       @overload
       def foo() -> int: ...
@@ -1450,8 +1462,10 @@ class ClassTest(_ParserTestBase):
           @property
           def a(self) -> int: ...
       """, """
+      from typing import Annotated
+
       class Foo:
-          a: int
+          a: Annotated[int, 'property']
       """)
 
   def test_duplicate_name(self):
@@ -1467,6 +1481,14 @@ class ClassTest(_ParserTestBase):
       """, 1, "Duplicate class-level identifier(s): bar")
     # Multiple method defs are ok (needed for variant signatures).
     self.check("""
+      class Foo:
+          @overload
+          def x(self) -> int: ...
+          @overload
+          def x(self) -> str: ...
+      """, """
+      from typing import overload
+
       class Foo:
           @overload
           def x(self) -> int: ...
@@ -1496,6 +1518,26 @@ class ClassTest(_ParserTestBase):
       class Foo(Protocol, Generic[T]): ...
     """)
 
+  def test_typing_extensions_parameterized_protocol(self):
+    self.check("""
+      from typing import TypeVar
+
+      from typing_extensions import Protocol
+
+      T = TypeVar('T')
+
+      class Foo(Protocol[T]): ...
+    """, """
+      from typing import Generic, TypeVar
+      import typing_extensions
+
+      from typing_extensions import Protocol
+
+      T = TypeVar('T')
+
+      class Foo(typing_extensions.Protocol, Generic[T]): ...
+    """)
+
   def test_bad_typevar_in_mutation(self):
     self.check_error("""
       from typing import Generic, TypeVar
@@ -1900,8 +1942,10 @@ class PropertyDecoratorTest(_ParserTestBase):
 
   def test_property_with_type(self):
     expected = """
+      from typing import Annotated
+
       class A:
-          name: str
+          name: Annotated[str, 'property']
     """
 
     # The return type of @property is used for the property type.
@@ -1916,10 +1960,10 @@ class PropertyDecoratorTest(_ParserTestBase):
           @name.setter
           def name(self, value: str) -> None: ...
       """, """
-      from typing import Any
+      from typing import Annotated, Any
 
       class A:
-          name: Any
+          name: Annotated[Any, 'property']
       """)
 
     self.check("""
@@ -1951,11 +1995,11 @@ class PropertyDecoratorTest(_ParserTestBase):
 
   def test_property_decorator_any_type(self):
     expected = """
-          from typing import Any
+          from typing import Annotated, Any
 
           class A:
-              name: Any
-              """
+              name: Annotated[Any, 'property']
+    """
 
     self.check("""
       class A:
@@ -2040,8 +2084,10 @@ class MergeSignaturesTest(_ParserTestBase):
           @property
           def name(self) -> str: ...
       """, """
+      from typing import Annotated
+
       class A:
-          name: str
+          name: Annotated[str, 'property']
       """)
 
   def test_method(self):
@@ -2055,6 +2101,8 @@ class MergeSignaturesTest(_ParserTestBase):
       def foo(x: int) -> str: ...
       def foo(x: str) -> str: ...""",
                      """
+      from typing import overload
+
       @overload
       def foo(x: int) -> str: ...
       @overload
@@ -2123,6 +2171,8 @@ class MergeSignaturesTest(_ParserTestBase):
           @abstractmethod
           def foo(x: int, y: int, z: int) -> str: ...
       """, """
+      from typing import overload
+
       class A:
           @abstractmethod
           @overload
@@ -2188,7 +2238,7 @@ class CanonicalPyiTest(_ParserTestBase):
         def foo(x: str) -> Any: ...
     """)
     expected = textwrap.dedent("""
-        from typing import Any
+        from typing import Any, overload
 
         @overload
         def foo(x: int = ...) -> Any: ...
@@ -2676,6 +2726,26 @@ class MethodAliasTest(_ParserTestBase):
     """)
 
 
+class AnnotatedTest(_ParserTestBase):
+  """Test typing.Annotated."""
+
+  def test_annotated(self):
+    self.check("""
+      from typing import Annotated
+
+      class Foo:
+          x: Annotated[int, 'a', 'b', 'c']
+    """)
+
+  def test_annotated_from_extensions(self):
+    self.check("""
+      from typing_extensions import Annotated
+
+      class Foo:
+          x: Annotated[int, 'a', 'b', 'c']
+    """)
+
+
 class ErrorTest(test_base.UnitTest):
   """Test parser errors."""
 
@@ -2715,5 +2785,129 @@ class ParamsTest(test_base.UnitTest):
       self.assertEqual(actual, expected)
 
 
+class ParamSpecTest(_ParserTestBase):
+
+  def test_from_typing(self):
+    self.check("""
+      from typing import Awaitable, Callable, ParamSpec, TypeVar
+
+      P = ParamSpec('P')
+      R = TypeVar('R')
+
+      def f(x: Callable[P, R]) -> Callable[P, Awaitable[R]]: ...
+    """, """
+      from typing import Awaitable, Callable, TypeVar
+
+      R = TypeVar('R')
+
+      def f(x: Callable[..., R]) -> Callable[..., Awaitable[R]]: ...
+    """)
+
+  def test_from_typing_extensions(self):
+    self.check("""
+      from typing import Awaitable, Callable, TypeVar
+
+      from typing_extensions import ParamSpec
+
+      P = ParamSpec('P')
+      R = TypeVar('R')
+
+      def f(x: Callable[P, R]) -> Callable[P, Awaitable[R]]: ...
+    """, """
+      from typing import Awaitable, Callable, TypeVar
+
+      from typing_extensions import ParamSpec
+
+      R = TypeVar('R')
+
+      def f(x: Callable[..., R]) -> Callable[..., Awaitable[R]]: ...
+    """)
+
+  @test_base.skip("ParamSpec in custom generic classes not supported yet")
+  def test_custom_generic(self):
+    self.check("""
+      from typing import Callable, Generic, ParamSpec, TypeVar
+
+      P = ParamSpec('P')
+      T = TypeVar('T')
+
+      class X(Generic[T, P]):
+          f: Callable[P, int]
+          x: T
+    """)
+
+  @test_base.skip("ParamSpec in custom generic classes not supported yet")
+  def test_double_brackets(self):
+    # Double brackets can be omitted when instantiating a class parameterized
+    # with only a single ParamSpec.
+    self.check("""
+      from typing import Generic, ParamSpec
+
+      P = ParamSpec('P')
+
+      class X(Generic[P]): ...
+
+      def f1(x: X[int, str]) -> None: ...
+      def f2(x: X[[int, str]]) -> None: ...
+    """, """
+      from typing import Generic, ParamSpec
+
+      P = ParamSpec('P')
+
+      class X(Generic[P]): ...
+
+      def f1(x: X[int, str]) -> None: ...
+      def f2(x: X[int, str]) -> None: ...
+    """)
+
+
+class ConcatenateTest(_ParserTestBase):
+
+  def test_from_typing(self):
+    self.check("""
+      from typing import Callable, Concatenate, ParamSpec, TypeVar
+
+      P = ParamSpec('P')
+      R = TypeVar('R')
+
+      class X: ...
+
+      def f(x: Callable[Concatenate[X, P], R]) -> Callable[P, R]: ...
+    """, """
+      from typing import Callable, TypeVar
+
+      R = TypeVar('R')
+
+      class X: ...
+
+      def f(x: Callable[..., R]) -> Callable[..., R]: ...
+    """)
+
+  def test_from_typing_extensions(self):
+    self.check("""
+      from typing import Callable, TypeVar
+
+      from typing_extensions import Concatenate, ParamSpec
+
+      P = ParamSpec('P')
+      R = TypeVar('R')
+
+      class X: ...
+
+      def f(x: Callable[Concatenate[X, P], R]) -> Callable[P, R]: ...
+    """, """
+      from typing import Callable, TypeVar
+
+      from typing_extensions import Concatenate
+      from typing_extensions import ParamSpec
+
+      R = TypeVar('R')
+
+      class X: ...
+
+      def f(x: Callable[..., R]) -> Callable[..., R]: ...
+    """)
+
+
 if __name__ == "__main__":
   unittest.main()
