@@ -63,19 +63,29 @@ def add_init_from_fields(
 
 
 def get_attributes(cls: pytd.Class):
-  """Get class attributes, filtering out properties."""
+  """Get class attributes, filtering out properties and ClassVars."""
   attributes = []
   for c in cls.constants:
     if isinstance(c.type, pytd.Annotated):
       if "'property'" not in c.type.annotations:
         c = c.Replace(type=c.type.base_type)
         attributes.append(c)
+    elif c.name == "__doc__":
+      # Filter docstrings out from the attribs list
+      # (we emit them as `__doc__ : str` in pyi output)
+      pass
+    elif c.type.name == "typing.ClassVar":  # pytype: disable=attribute-error
+      # We do not want classvars treated as attribs
+      pass
     else:
       attributes.append(c)
   return tuple(attributes)
 
 
 def add_generated_init(cls: pytd.Class) -> pytd.Class:
+  # Do not override an __init__ from the pyi file
+  if any(x.name == "__init__" for x in cls.methods):
+    return cls
   fields = get_attributes(cls)
   return add_init_from_fields(cls, fields)
 
