@@ -21,7 +21,9 @@ _BUILTINS = """
 
 
 def pytd_src(text):
-  return textwrap.dedent(escape.preprocess_pytd(text))
+  text = textwrap.dedent(escape.preprocess_pytd(text))
+  text = text.replace("`", "")
+  return text
 
 
 class TestTypeMatch(parser_test_base.ParserTest):
