@@ -245,8 +245,10 @@ class BinaryPredicate(ObjectPredicate):
   """
 
   def run(self, node, args, result):
-    for left in args.posargs[0].bindings:
-      for right in args.posargs[1].bindings:
+    for left in abstract_utils.expand_type_parameter_instances(
+        args.posargs[0].bindings):
+      for right in abstract_utils.expand_type_parameter_instances(
+          args.posargs[1].bindings):
         node, pyval = self._call_predicate(node, left, right)
         result.AddBinding(self._vm_values[pyval],
                           source_set=(left, right), where=node)
@@ -525,9 +527,9 @@ class Super(BuiltinClass):
             self.vm.frames, message="Missing __class__ closure for super call.",
             details="Is 'super' being called from a method defined in a class?")
         return node, self.vm.new_unsolvable(node)
-      # The implicit super object argument is the first positional argument to
-      # the function calling 'super'.
-      self_arg = frame.first_posarg
+      # The implicit super object argument is the first argument to the function
+      # calling 'super'.
+      self_arg = frame.first_arg
       if not self_arg:
         self.vm.errorlog.invalid_super_call(
             self.vm.frames, message="Missing 'self' argument to 'super' call.")
