@@ -33,7 +33,7 @@ ExpectedBuildStatement = collections.namedtuple(
 _PREAMBLE_LENGTH = 6
 
 
-class FakeImportGraph(object):
+class FakeImportGraph:
   """Just enough of the ImportGraph interface to run tests."""
 
   def __init__(self, source_files, provenance, source_to_deps):
@@ -69,7 +69,7 @@ class TestDepsFromImportGraph(unittest.TestCase):
   """Test deps_from_import_graph."""
 
   def setUp(self):
-    super(TestDepsFromImportGraph, self).setUp()
+    super().setUp()
     init = ImportlabModule('/foo/bar/__init__.py', 'bar/__init__.py', 'bar')
     a = ImportlabModule('/foo/bar/a.py', 'bar/a.py', 'bar.a')
     b = ImportlabModule('/foo/bar/b.py', 'bar/b.py', 'bar.b')
@@ -132,7 +132,7 @@ class TestBase(unittest.TestCase):
 
   @classmethod
   def setUpClass(cls):
-    super(TestBase, cls).setUpClass()
+    super().setUpClass()
     cls.parser = parse_args.make_parser()
 
 
@@ -140,7 +140,7 @@ class TestCustomOptions(TestBase):
   """Test PytypeRunner.set_custom_options."""
 
   def setUp(self):
-    super(TestCustomOptions, self).setUp()
+    super().setUp()
     self.conf = self.parser.config_from_defaults()
 
   # --disable tests a flag with a string value.
@@ -166,7 +166,7 @@ class TestCustomOptions(TestBase):
     runner = make_runner([], [], self.conf)
     binary_flags = {'--no-report-errors'}
     runner.set_custom_options({}, binary_flags)
-    self.assertFalse(binary_flags)
+    self.assertEqual(binary_flags, set())
 
   def test_no_report_errors(self):
     self.conf.report_errors = False
@@ -180,7 +180,7 @@ class TestCustomOptions(TestBase):
     runner = make_runner([], [], self.conf)
     binary_flags = set()
     runner.set_custom_options({}, binary_flags)
-    self.assertFalse(binary_flags)
+    self.assertEqual(binary_flags, set())
 
   # --protocols tests a binary flag whose value is passed through transparently.
 
@@ -196,21 +196,21 @@ class TestCustomOptions(TestBase):
     runner = make_runner([], [], self.conf)
     binary_flags = {'--protocols'}
     runner.set_custom_options({}, binary_flags)
-    self.assertFalse(binary_flags)
+    self.assertEqual(binary_flags, set())
 
   def test_no_protocols_default(self):
     self.conf.protocols = False
     runner = make_runner([], [], self.conf)
     binary_flags = set()
     runner.set_custom_options({}, binary_flags)
-    self.assertFalse(binary_flags)
+    self.assertEqual(binary_flags, set())
 
 
 class TestGetRunCmd(TestBase):
   """Test PytypeRunner.get_pytype_command_for_ninja()."""
 
   def setUp(self):
-    super(TestGetRunCmd, self).setUp()
+    super().setUp()
     self.runner = make_runner([], [], self.parser.config_from_defaults())
 
   def get_options(self, args):
@@ -221,7 +221,7 @@ class TestGetRunCmd(TestBase):
     self.assertEqual(end-start, 1)
     args.pop(end)
     args.pop(start)
-    return pytype_config.Options(args)
+    return pytype_config.Options(args, command_line=True)
 
   def get_basic_options(self, report_errors=False):
     return self.get_options(
@@ -294,8 +294,8 @@ class TestYieldSortedModules(TestBase):
          expected_stage) in expected_list:
       try:
         mod, actual_report_errors, actual_deps, actual_stage = next(mod_gen)
-      except StopIteration:
-        raise AssertionError('Not enough modules')
+      except StopIteration as e:
+        raise AssertionError('Not enough modules') from e
       self.assertEqual(mod, expected_mod)
       self.assertEqual(actual_report_errors, expected_report_errors)
       self.assertEqual(actual_deps, expected_deps)
@@ -458,7 +458,7 @@ class TestNinjaBody(TestBase):
   """Test PytypeRunner.setup_build."""
 
   def setUp(self):
-    super(TestNinjaBody, self).setUp()
+    super().setUp()
     self.conf = self.parser.config_from_defaults()
 
   def assertBuildStatementMatches(self, build_statement, expected):
@@ -600,7 +600,7 @@ class TestImports(TestBase):
   """Test imports-related functionality."""
 
   def setUp(self):
-    super(TestImports, self).setUp()
+    super().setUp()
     self.conf = self.parser.config_from_defaults()
 
   def test_write_default_pyi(self):
