@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import json
 import textwrap
 
@@ -16,7 +14,7 @@ from pytype.tools.xref import kythe
 from pytype.tools.xref import output
 
 
-class IndexerTestMixin(object):
+class IndexerTestMixin:
   """Mixin for indexer tests."""
 
   def index_code(self, code, **kwargs):
@@ -258,12 +256,12 @@ class IndexerTestPy3(test_base.TargetPython3BasicTest, IndexerTestMixin):
   def index_code(self, code, *args, **kwargs):
     if utils.USE_ANNOTATIONS_BACKPORT and self.python_version == (2, 7):
       code = test_base.WithAnnotationsImport(code)
-    return super(IndexerTestPy3, self).index_code(code, *args, **kwargs)
+    return super().index_code(code, *args, **kwargs)
 
   def assertDefLocs(self, index, fqname, locs):
     if utils.USE_ANNOTATIONS_BACKPORT and self.python_version == (2, 7):
       locs = [(line + 1, col) for line, col in locs]
-    return super(IndexerTestPy3, self).assertDefLocs(index, fqname, locs)
+    return super().assertDefLocs(index, fqname, locs)
 
   def test_type_annotations(self):
     ix = self.index_code("""
